@@ -1,7 +1,5 @@
-package Test::BDD::Cucumber;
-$Test::BDD::Cucumber::VERSION = '0.84';
-use strict;
-use warnings;
+package Test::BDD::Cucumber 0.87;
+
 1;
 
 # CODE ENDS
@@ -12,7 +10,7 @@ Test::BDD::Cucumber - Feature-complete Cucumber-style testing in Perl
 
 =head1 VERSION
 
-version 0.84
+version 0.87
 
 =head1 SYNOPSIS
 
